@@ -1,17 +1,20 @@
+from __future__ import with_statement
 from itertools import cycle
 from signal import signal, SIGWINCH
 
-from noseprogressive.terminal import height_and_width
 from noseprogressive.utils import nose_selector
 
 
+__all__ = ['ProgressBar', 'NullProgressBar']
+
+
 class ProgressBar(object):
     SPINNER_CHARS = r'/-\|'
     _is_dodging = 0  # Like a semaphore
 
-    def __init__(self, stream, max, term):
+    def __init__(self, max, term):
         """max is the highest value I will attain. Must be >0."""
-        self.stream = stream
+        self.stream = term.stream
         self.max = max
         self._term = term
         self.last = ''  # The contents of the previous progress line printed
@@ -20,7 +23,7 @@ class ProgressBar(object):
         signal(SIGWINCH, self._handle_winch)
 
     def _measure_terminal(self):
-        self.lines, self.cols = height_and_width()
+        self.lines, self.cols = self._term.height, self._term.width
 
     def _handle_winch(self, *args):
         #self.erase()  # Doesn't seem to help.
@@ -70,7 +73,7 @@ class ProgressBar(object):
 
     def _at_last_line(self):
         """Return a context manager that positions the cursor at the last line, lets you write things, and then returns it to its previous position."""
-        return AtLine(self.stream, self.lines, self._term)
+        return self._term.location(0, self.lines)
 
     def dodging(bar):
         """Return a context manager which erases the bar, lets you output things, and then redraws the bar.
@@ -104,18 +107,22 @@ class ProgressBar(object):
         return ShyProgressBar()
 
 
-class AtLine(object):
-    """Context manager which moves the cursor to a certain line on entry and goes back to where it was on exit"""
+class Null(object):
+    def __getattr__(self, *args, **kwargs):
+        """Return a boring callable for any attribute accessed."""
+        return lambda *args, **kwargs: None
 
-    def __init__(self, stream, line, term):
-        self.stream = stream
-        self.line = line
-        self._term = term
+    # Beginning in Python 2.7, __enter__ and __exit__ aren't looked up through
+    # __getattr__ or __getattribute__:
+    # http://docs.python.org/reference/datamodel#specialnames
+    __enter__ = __exit__ = __getattr__
 
-    def __enter__(self):
-        """Save position and move to progress bar, col 1."""
-        self.stream.write(self._term.save)  # save position
-        self.stream.write(self._term.position(self.line, 0))
 
-    def __exit__(self, type, value, tb):
-        self.stream.write(self._term.restore)  # restore position
+class NullProgressBar(Null):
+    """``ProgressBar`` workalike that does nothing
+
+    Comes in handy when you want to have an option to hide the progress bar.
+
+    """
+    def dodging(self):
+        return Null()  # So Python can call __enter__ and __exit__ on it
